@@ -4,6 +4,7 @@ from typing import List, Optional
 import infima_client.core.api.prediction_v1.prediction_v1_get as _get
 import infima_client.core.api.prediction_v1.prediction_v1_get_available_as_ofs as _get_available_as_ofs
 import infima_client.core.api.prediction_v1.prediction_v1_get_latest_as_of as _get_latest_as_of
+import infima_client.core.api.prediction_v1.prediction_v1_get_n_months_ahead as _get_n_months_ahead
 import infima_client.core.api.prediction_v1.prediction_v1_get_one_month_ahead as _get_one_month_ahead
 import infima_client.core.api.prediction_v1.prediction_v1_get_service_info as _get_service_info
 from infima_client.api.utils import unwrap_or_unset
@@ -17,6 +18,8 @@ from infima_client.core.models import (
     PredictionV1GetAvailableAsOfsResponse,
     PredictionV1GetLatestAsOfRequest,
     PredictionV1GetLatestAsOfResponse,
+    PredictionV1GetNMonthsAheadRequest,
+    PredictionV1GetNMonthsAheadResponse,
     PredictionV1GetOneMonthAheadRequest,
     PredictionV1GetOneMonthAheadResponse,
     PredictionV1GetRequest,
@@ -66,16 +69,45 @@ class PredictionV1:
             raise ValueError("no data returned from the service")
         return response
 
+    def get_n_months_ahead(
+        self,
+        *,
+        num_months: int,
+        symbols: List[str],
+        factor_date_range: Optional[CoreFactorDateRange] = None,
+        return_all_as_ofs: Optional[bool] = None,
+    ) -> PredictionV1GetNMonthsAheadResponse:
+        _num_months = num_months
+        _symbols = symbols
+        _factor_date_range = unwrap_or_unset(factor_date_range)
+        _return_all_as_ofs = unwrap_or_unset(return_all_as_ofs)
+        json_body = PredictionV1GetNMonthsAheadRequest(
+            num_months=_num_months,
+            symbols=_symbols,
+            factor_date_range=_factor_date_range,
+            return_all_as_ofs=_return_all_as_ofs,
+        )
+        response = _get_n_months_ahead.sync(client=self.client, json_body=json_body)
+        if isinstance(response, GoogleRpcStatus):
+            raise ValueError(response.message)
+        if response is None:
+            raise ValueError("no data returned from the service")
+        return response
+
     def get_one_month_ahead(
         self,
         *,
         symbols: List[str],
         factor_date_range: Optional[CoreFactorDateRange] = None,
+        return_all_as_ofs: Optional[bool] = None,
     ) -> PredictionV1GetOneMonthAheadResponse:
         _symbols = symbols
         _factor_date_range = unwrap_or_unset(factor_date_range)
+        _return_all_as_ofs = unwrap_or_unset(return_all_as_ofs)
         json_body = PredictionV1GetOneMonthAheadRequest(
-            symbols=_symbols, factor_date_range=_factor_date_range
+            symbols=_symbols,
+            factor_date_range=_factor_date_range,
+            return_all_as_ofs=_return_all_as_ofs,
         )
         response = _get_one_month_ahead.sync(client=self.client, json_body=json_body)
         if isinstance(response, GoogleRpcStatus):
