@@ -115,6 +115,7 @@ class InfimaClient:
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_as_of_predictions(
             client=self,
@@ -123,6 +124,7 @@ class InfimaClient:
             col=col,
             wide=wide,
             progress=progress,
+            chunk_size=chunk_size,
         )
 
     def get_n_months_ahead_predictions(
@@ -134,6 +136,7 @@ class InfimaClient:
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_n_months_ahead_predictions(
             client=self,
@@ -144,6 +147,7 @@ class InfimaClient:
             col=col,
             wide=wide,
             progress=progress,
+            chunk_size=chunk_size,
         )
 
     def get_preds(self, symbols: List[str], **kwargs: Any) -> Optional[pd.DataFrame]:
@@ -169,6 +173,7 @@ class InfimaClient:
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_pool_actuals(
             client=self,
@@ -178,6 +183,7 @@ class InfimaClient:
             col=col,
             wide=wide,
             progress=progress,
+            chunk_size=chunk_size,
         )
 
     def get_cohort_actuals(
@@ -188,6 +194,7 @@ class InfimaClient:
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_cohort_actuals(
             client=self,
@@ -197,6 +204,7 @@ class InfimaClient:
             col=col,
             wide=wide,
             progress=progress,
+            chunk_size=chunk_size,
         )
 
     def get_actuals(
@@ -207,6 +215,7 @@ class InfimaClient:
         col: Optional[str] = "cpr",
         wide: bool = True,
         progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_actuals(
             client=self,
@@ -216,25 +225,58 @@ class InfimaClient:
             col=col,
             wide=wide,
             progress=progress,
+            chunk_size=chunk_size,
         )
 
-    def check_cohort_coverage(self, cohorts: List[str]) -> Optional[pd.DataFrame]:
-        return infima_client.extras.check_cohort_coverage(client=self, cohorts=cohorts)
+    def check_cohort_coverage(
+        self,
+        cohorts: List[str],
+        progress: bool = True,
+        chunk_size: Optional[int] = None,
+    ) -> Optional[pd.DataFrame]:
+        return infima_client.extras.check_cohort_coverage(
+            client=self, cohorts=cohorts, progress=progress, chunk_size=chunk_size
+        )
 
-    def check_coverage(self, cusips: List[str]) -> Optional[pd.DataFrame]:
-        return infima_client.extras.check_coverage(client=self, cusips=cusips)
+    def check_coverage(
+        self,
+        cusips: List[str],
+        progress: bool = True,
+        chunk_size: Optional[int] = None,
+    ) -> Optional[pd.DataFrame]:
+        return infima_client.extras.check_coverage(
+            client=self, cusips=cusips, progress=progress, chunk_size=chunk_size
+        )
 
     def get_cohort_summary(
         self,
         cohorts: List[str],
         factor_date: Optional[DateT] = None,
+        progress: bool = True,
+        chunk_size: Optional[int] = None,
     ) -> Optional[pd.DataFrame]:
         return infima_client.extras.get_cohort_summary(
-            client=self, cohorts=cohorts, factor_date=factor_date
+            client=self,
+            cohorts=cohorts,
+            factor_date=factor_date,
+            progress=progress,
+            chunk_size=chunk_size,
         )
 
-    def get_pool_attributes(self, cusips: List[str]) -> Optional[pd.DataFrame]:
-        return infima_client.extras.get_pool_attributes(client=self, cusips=cusips)
+    def get_pool_attributes(
+        self,
+        cusips: List[str],
+        factor_date: Optional[DateT] = None,
+        progress: bool = True,
+        chunk_size: Optional[int] = None,
+    ) -> Optional[pd.DataFrame]:
+        return infima_client.extras.get_pool_attributes(
+            client=self,
+            cusips=cusips,
+            factor_date=factor_date,
+            progress=progress,
+            chunk_size=chunk_size,
+        )
 
     def get_member_lists(
         self, cohorts: List[str], factor_date: Optional[DateT] = None
