@@ -53,6 +53,9 @@ from infima_client.core.models.cohort.v1.get_cohort_summary_response import (
 from infima_client.core.models.cohort.v1.get_cohort_summary_response_summary import (
     CohortV1GetCohortSummaryResponseSummary,
 )
+from infima_client.core.models.cohort.v1.get_covered_cohorts_response import (
+    CohortV1GetCoveredCohortsResponse,
+)
 from infima_client.core.models.cohort.v1.get_member_lists_request import (
     CohortV1GetMemberListsRequest,
 )
