@@ -22,7 +22,7 @@ T = TypeVar("T", bound="CohortV1CheckCoverageRequest")
 class CohortV1CheckCoverageRequest:
     """
     Attributes:
-        cohorts (List[str]): Cohorts to check coverage. Example: FNCL 2.0 2021.
+        cohorts (List[str]): Cohorts to check coverage Example: ['FNCL 2.0 2021', 'FNCL 2.5 2021'].
     """
 
     cohorts: List[str]
