@@ -8,7 +8,6 @@ from typing import (
     Tuple,
     Type,
     TypeVar,
-    Union,
     cast,
 )
 
@@ -23,29 +22,29 @@ T = TypeVar("T", bound="PoolV1CheckCoverageRequest")
 class PoolV1CheckCoverageRequest:
     """
     Attributes:
-        cusips (Union[Unset, List[str]]): CUSIPs to check coverage for. Example: 31417EUD1.
+        cusips (List[str]): CUSIPs to check coverage for. Example: ['31417EUD1'].
     """
 
-    cusips: Union[Unset, List[str]] = UNSET
+    cusips: List[str]
     additional_properties: Dict[str, Any] = field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        cusips: Union[Unset, List[str]] = UNSET
-        if not isinstance(self.cusips, Unset):
-            cusips = self.cusips
+        cusips = self.cusips
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
-        if cusips is not UNSET:
-            field_dict["cusips"] = cusips
+        field_dict.update(
+            {
+                "cusips": cusips,
+            }
+        )
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        cusips = cast(List[str], d.pop("cusips", UNSET))
+        cusips = cast(List[str], d.pop("cusips"))
 
         pool_v1_check_coverage_request = cls(
             cusips=cusips,
