@@ -38,6 +38,7 @@ class PoolV1FindRequest:
         collateral_type (Union[Unset, MbsCollateralType]):  Default: MbsCollateralType.NULL_COLLATERAL_TYPE.
         coupon_range (Union[Unset, CorePositiveRange]):
         coupon_type (Union[Unset, MbsCouponType]):  Default: MbsCouponType.NULL_COUPON_TYPE.
+        cusips (Union[Unset, List[str]]):
         eligible_tba_only (Union[Unset, bool]):
         factor_date (Union[Unset, CoreFactorDate]):
         issue_date_range (Union[Unset, CoreDateRange]):
@@ -67,6 +68,7 @@ class PoolV1FindRequest:
     ] = MbsCollateralType.NULL_COLLATERAL_TYPE
     coupon_range: Union[Unset, CorePositiveRange] = UNSET
     coupon_type: Union[Unset, MbsCouponType] = MbsCouponType.NULL_COUPON_TYPE
+    cusips: Union[Unset, List[str]] = UNSET
     eligible_tba_only: Union[Unset, bool] = UNSET
     factor_date: Union[Unset, CoreFactorDate] = UNSET
     issue_date_range: Union[Unset, CoreDateRange] = UNSET
@@ -113,6 +115,10 @@ class PoolV1FindRequest:
         if not isinstance(self.coupon_type, Unset):
             coupon_type = self.coupon_type.value
 
+        cusips: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.cusips, Unset):
+            cusips = self.cusips
+
         eligible_tba_only = self.eligible_tba_only
         factor_date: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.factor_date, Unset):
@@ -196,6 +202,8 @@ class PoolV1FindRequest:
             field_dict["couponRange"] = coupon_range
         if coupon_type is not UNSET:
             field_dict["couponType"] = coupon_type
+        if cusips is not UNSET:
+            field_dict["cusips"] = cusips
         if eligible_tba_only is not UNSET:
             field_dict["eligibleTbaOnly"] = eligible_tba_only
         if factor_date is not UNSET:
@@ -282,6 +290,8 @@ class PoolV1FindRequest:
         else:
             coupon_type = MbsCouponType(_coupon_type)
 
+        cusips = cast(List[str], d.pop("cusips", UNSET))
+
         eligible_tba_only = d.pop("eligibleTbaOnly", UNSET)
 
         _factor_date = d.pop("factorDate", UNSET)
@@ -402,6 +412,7 @@ class PoolV1FindRequest:
             collateral_type=collateral_type,
             coupon_range=coupon_range,
             coupon_type=coupon_type,
+            cusips=cusips,
             eligible_tba_only=eligible_tba_only,
             factor_date=factor_date,
             issue_date_range=issue_date_range,
