@@ -24,7 +24,7 @@ T = TypeVar("T", bound="PoolV1GetActualPrepaymentsRequest")
 class PoolV1GetActualPrepaymentsRequest:
     """
     Attributes:
-        cusips (List[str]): Pools to fetch. Example: 31417EUD1.
+        cusips (List[str]): Pools to fetch. Example: ['31417EUD1'].
         factor_date_range (Union[Unset, CoreFactorDateRange]):
     """
 
