@@ -24,7 +24,7 @@ T = TypeVar("T", bound="PoolV1GetCharacteristicsRequest")
 class PoolV1GetCharacteristicsRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch characteristics. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch characteristics. Example: ['31417EUD1'].
         factor_date (Union[Unset, CoreFactorDate]):
     """
 
