@@ -22,7 +22,7 @@ T = TypeVar("T", bound="PoolV1GetGeographicDistributionRequest")
 class PoolV1GetGeographicDistributionRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch geographical distributions. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch geographical distributions. Example: ['31417EUD1'].
     """
 
     cusips: List[str]
