@@ -22,7 +22,7 @@ T = TypeVar("T", bound="PoolV1GetQuartilesRequest")
 class PoolV1GetQuartilesRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch quartiles. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch quartiles. Example: ['31417EUD1'].
     """
 
     cusips: List[str]
