@@ -8,11 +8,13 @@ from typing import (
     Tuple,
     Type,
     TypeVar,
+    Union,
     cast,
 )
 
 from attr import define, field
 
+from infima_client.core.models.core.factor_date import CoreFactorDate
 from infima_client.core.types import UNSET, Unset
 
 T = TypeVar("T", bound="PoolV1GetRequest")
@@ -22,15 +24,21 @@ T = TypeVar("T", bound="PoolV1GetRequest")
 class PoolV1GetRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch Pool information. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch Pool information. Example: ['31417EUD1'].
+        factor_date (Union[Unset, CoreFactorDate]):
     """
 
     cusips: List[str]
+    factor_date: Union[Unset, CoreFactorDate] = UNSET
     additional_properties: Dict[str, Any] = field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         cusips = self.cusips
 
+        factor_date: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.factor_date, Unset):
+            factor_date = self.factor_date.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -38,6 +46,8 @@ class PoolV1GetRequest:
                 "cusips": cusips,
             }
         )
+        if factor_date is not UNSET:
+            field_dict["factorDate"] = factor_date
 
         return field_dict
 
@@ -46,8 +56,16 @@ class PoolV1GetRequest:
         d = src_dict.copy()
         cusips = cast(List[str], d.pop("cusips"))
 
+        _factor_date = d.pop("factorDate", UNSET)
+        factor_date: Union[Unset, CoreFactorDate]
+        if isinstance(_factor_date, Unset):
+            factor_date = UNSET
+        else:
+            factor_date = CoreFactorDate.from_dict(_factor_date)
+
         pool_v1_get_request = cls(
             cusips=cusips,
+            factor_date=factor_date,
         )
 
         pool_v1_get_request.additional_properties = d
