@@ -22,7 +22,7 @@ T = TypeVar("T", bound="PoolV1GetServicersRequest")
 class PoolV1GetServicersRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch servicers. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch servicers. Example: ['31417EUD1'].
     """
 
     cusips: List[str]
