@@ -2,7 +2,7 @@ from .actuals import get_actuals, get_cohort_actuals, get_pool_actuals
 from .attributes import get_cohort_summary, get_pool_attributes
 from .cohorts import get_member_lists
 from .coverage import check_cohort_coverage, check_coverage
-from .predictions import get_predictions
+from .predictions import get_as_of_predictions, get_n_months_ahead_predictions
 
 __all__ = [
     "check_cohort_coverage",
@@ -11,7 +11,8 @@ __all__ = [
     "get_cohort_actuals",
     "get_cohort_summary",
     "get_member_lists",
+    "get_n_months_ahead_predictions",
     "get_pool_actuals",
     "get_pool_attributes",
-    "get_predictions",
+    "get_as_of_predictions",
 ]
