@@ -1,5 +1,6 @@
 import datetime
 import math
+import re
 import sys
 import time
 from functools import partial, wraps
@@ -11,7 +12,6 @@ else:  # for Python<3.8
     from typing_extensions import Protocol
 
 import pandas as pd
-import stringcase
 import tqdm
 from more_itertools import chunked
 
@@ -25,6 +25,34 @@ DateT = Union[str, datetime.date, pd.Timestamp]
 KNOWN_DATE_COLUMNS = ["asOf", "factorDate", "issueDate", "maturityDate"]
 
 
+def lowercase(string):
+    """Convert string into lower case.
+    Args:
+        string: String to convert.
+    Returns:
+        string: Lowercase case string.
+    """
+
+    return str(string).lower()
+
+
+def snakecase(string):
+    """Convert string into snake case.
+    Join punctuation with underscore
+    Args:
+        string: String to convert.
+    Returns:
+        string: Snake cased string.
+    """
+
+    string = re.sub(r"[\-\.\s]", "_", str(string))
+    if not string:
+        return string
+    return lowercase(string[0]) + re.sub(
+        r"[A-Z]", lambda matched: "_" + lowercase(matched.group(0)), string[1:]
+    )
+
+
 def handle_date(dt: DateT) -> CoreDate:
     """Convert date object to CoreDate."""
     _dt = pd.Timestamp(dt).date()
@@ -54,7 +82,7 @@ def handle_factor_date_range(
 
 def maybe_parse_known_date_columns(df: pd.DataFrame) -> pd.DataFrame:
     for col in KNOWN_DATE_COLUMNS:
-        df = maybe_parse_date_column(df, stringcase.snakecase(col))
+        df = maybe_parse_date_column(df, snakecase(col))
         df = maybe_parse_date_column(df, col)
     return df
 
@@ -72,7 +100,7 @@ def _parse_nested_date(df: pd.DataFrame, col: str) -> pd.DataFrame:
     exploded = pd.json_normalize(dt)
     if "day" not in exploded.columns:
         exploded["day"] = 1
-    df[stringcase.snakecase(col)] = pd.to_datetime(exploded).to_numpy()
+    df[snakecase(col)] = pd.to_datetime(exploded).to_numpy()
     return df
 
 
@@ -91,7 +119,7 @@ def _parse_exploded_date(df: pd.DataFrame, col: str) -> pd.DataFrame:
     else:
         dt_args["day"] = 1
 
-    df[stringcase.snakecase(col)] = pd.to_datetime(dt_args).to_numpy()
+    df[snakecase(col)] = pd.to_datetime(dt_args).to_numpy()
     return df.drop(to_drop, axis=1)
 
 
@@ -104,7 +132,7 @@ def maybe_explode_columns(
     for col in cols:
         if col not in df.columns:
             continue
-        exploded = pd.json_normalize(df[col]).rename(columns=stringcase.snakecase)
+        exploded = pd.json_normalize(df[col]).rename(columns=snakecase)
         df.drop(col, axis=1, inplace=True)
         df = pd.concat([df, exploded], axis=1)
 
@@ -234,7 +262,7 @@ def nested_dict_to_frame(
         df = (
             pd.DataFrame.from_records(recs)
             .pipe(maybe_parse_known_date_columns)
-            .rename(columns=stringcase.snakecase)
+            .rename(columns=snakecase)
         )
         if set_index:
             df = df.set_index(index_levels)
@@ -252,7 +280,7 @@ def simple_dict_to_frame(
     df = (
         pd.DataFrame.from_dict(data, orient="index")
         .pipe(maybe_parse_known_date_columns)
-        .rename(columns=stringcase.snakecase)
+        .rename(columns=snakecase)
     )
     df.index = df.index.rename(index_name)
     return df
